@@ -338,7 +338,7 @@ class Utils:
 @click.option('-t', '--target', type=Path, default=Path.cwd(),
               help='Target repository (default is current directory)')
 @click.option('-r', '--merge-request', is_flag=True, default=False,
-              help='Create merge request. Requires --push (default is False)')
+              help='Create merge request. Requires --push. (default is False)')
 def cli(issue_id_or_url, name_only, push, target: Path, merge_request):
     """Simple program that takes a JIRA issue ID and creates a new local and tracking remote branch"""
 
